#########
universal
#########

The checks on the `universal` profile, documented below, evaluate adherence to the best practices shared among the type design community. Additionally, it also includes the checks from the :doc:`opentype` profile.

.. automodule:: fontbakery.profiles.universal
   :members:
   :undoc-members:
